@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-18'; # DATE
+our $DATE = '2023-04-25'; # DATE
 our $DIST = 'Data-Sah-Filter'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 sub meta {
     +{
@@ -53,7 +53,7 @@ Data::Sah::Filter::perl::Array::uniq - Make an array uniq using List::Util's uni
 
 =head1 VERSION
 
-This document describes version 0.015 of Data::Sah::Filter::perl::Array::uniq (from Perl distribution Data-Sah-Filter), released on 2022-10-18.
+This document describes version 0.016 of Data::Sah::Filter::perl::Array::uniq (from Perl distribution Data-Sah-Filter), released on 2023-04-25.
 
 =head1 SYNOPSIS
 
@@ -94,9 +94,9 @@ Source repository is at L<https://github.com/perlancar/perl-Data-Sah-Filter>.
 
 =head1 SEE ALSO
 
-Related filters: L<Float::check_has_fraction|Data::Sah::Filter::perl::Float::check_has_fraction>.
+L<Data::Sah::Filter::perl::Array::check_uniq>.
 
-L<Data::Sah::Filter::perl::Array::uniqnum>
+L<Data::Sah::Filter::perl::Array::uniqnum>, L<Data::Sah::Filter::perl::Array::uniqstr>.
 
 =head1 AUTHOR
 
@@ -122,7 +122,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
